==> helm-annotations-2.9.0-sources.jar: io/dekorate/helm/config/MaintainerBuilder.java <==
package io.dekorate.helm.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class MaintainerBuilder extends io.dekorate.helm.config.MaintainerFluentImpl<io.dekorate.helm.config.MaintainerBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.dekorate.helm.config.Maintainer,io.dekorate.helm.config.MaintainerBuilder>{
  public MaintainerBuilder() {
    this(false);
  }
  public MaintainerBuilder(java.lang.Boolean validationEnabled) {
    this(new Maintainer(), validationEnabled);
  }
  public MaintainerBuilder(io.dekorate.helm.config.MaintainerFluent<?> fluent) {
    this(fluent, false);
  }
  public MaintainerBuilder(io.dekorate.helm.config.MaintainerFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Maintainer(), validationEnabled);
  }
  public MaintainerBuilder(io.dekorate.helm.config.MaintainerFluent<?> fluent,io.dekorate.helm.config.Maintainer instance) {
    this(fluent, instance, false);
  }
  public MaintainerBuilder(io.dekorate.helm.config.MaintainerFluent<?> fluent,io.dekorate.helm.config.Maintainer instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withEmail(instance.getEmail()); 
    fluent.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  public MaintainerBuilder(io.dekorate.helm.config.Maintainer instance) {
    this(instance,false);
  }
  public MaintainerBuilder(io.dekorate.helm.config.Maintainer instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withEmail(instance.getEmail()); 
    this.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.helm.config.MaintainerFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.dekorate.helm.config.EditableMaintainer build() {
    EditableMaintainer buildable = new EditableMaintainer(fluent.getName(),fluent.getEmail(),fluent.getUrl());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MaintainerBuilder that = (MaintainerBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> helm-annotations-2.11.5-sources.jar: io/dekorate/helm/config/MaintainerBuilder.java <==
package io.dekorate.helm.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class MaintainerBuilder extends MaintainerFluentImpl<MaintainerBuilder> implements VisitableBuilder<io.dekorate.helm.config.Maintainer,io.dekorate.helm.config.MaintainerBuilder>{
  public MaintainerBuilder() {
    this(false);
  }
  public MaintainerBuilder(Boolean validationEnabled) {
    this(new Maintainer(), validationEnabled);
  }
  public MaintainerBuilder(MaintainerFluent<?> fluent) {
    this(fluent, false);
  }
  public MaintainerBuilder(io.dekorate.helm.config.MaintainerFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Maintainer(), validationEnabled);
  }
  public MaintainerBuilder(io.dekorate.helm.config.MaintainerFluent<?> fluent,io.dekorate.helm.config.Maintainer instance) {
    this(fluent, instance, false);
  }
  public MaintainerBuilder(io.dekorate.helm.config.MaintainerFluent<?> fluent,io.dekorate.helm.config.Maintainer instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withEmail(instance.getEmail()); 
    fluent.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  public MaintainerBuilder(io.dekorate.helm.config.Maintainer instance) {
    this(instance,false);
  }
  public MaintainerBuilder(io.dekorate.helm.config.Maintainer instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withEmail(instance.getEmail()); 
    this.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.helm.config.MaintainerFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public EditableMaintainer build() {
    EditableMaintainer buildable = new EditableMaintainer(fluent.getName(),fluent.getEmail(),fluent.getUrl());
    return buildable;
  }
  
}
